//
//The Lua for Nick's I/O functionality
//Entire lua code made by SMS Alfredo
//

local NICK_PATH = "client/Nick/"
local NICK_SAVE_PATHS = {
	"PowersColor.dat", "Legacy.dat", "Looking.dat"}
	
local NICK_SAVE_COMMANDS = {
	"nick_powerscolor", "nick_legacy", "nick_looking"}

//Table/string conversion functions

local tabletostring = function(table)
	local chars = ""
	for id, value in pairs(table)
		chars = $..tostring(id).." "..tostring(value).." "
	end
	return chars
end

local stringtotable = function(chars)
	local table = {}
	local id
	for value in string.gmatch(chars, "[^%s]+") do
		if id == nil
			id = tonumber(value)
			if id == nil
				id = value
			end
		else
			table[id] = value
			id = nil
		end
	end
	return table
end

//Command to receive Mario's IO saves using a compressed string
COM_AddCommand("nick_io", function(player, arg)
	//Say we've used this command
	if player.nickdidio then return end
	player.nickdidio = true
	
	//Convert save to table
	local save = arg and stringtotable(arg)
	
	//Iterate through table and apply field values
	if save
		for id, field in ipairs(NICK_SAVE_COMMANDS)
			local value = save[id]
			if value != nil
				_G[field](player, value) //Execute command
			end
		end
	end
end)

//Apply the I/O for the netgame commands when spawning
addHook("PlayerSpawn", function(player)
	if player != consoleplayer or player.nickdidio or not io then return end
	
	//Go through all the I/O files, putting their values in a table
	local save = {}
	local hasvalues = false
	for id, field in ipairs(NICK_SAVE_COMMANDS)
		local file = io.openlocal(NICK_PATH + NICK_SAVE_PATHS[id])
		if file
			local value = file:read("*l")
			if value != nil
				if field == "nick_powerscolor"
					save[id] = R_GetColorByName(value)
				else
					save[id] = tonumber(value)
				end
				hasvalues = $ or save[id]
			end
			file:close()
		end
	end
	
	//Send the table to the server by converting it to a string
	if hasvalues
		local string = tabletostring(save)
		if string
			COM_BufInsertText(consoleplayer, "nick_io \""..string.."\"")
		end
	else
		COM_BufInsertText(consoleplayer, "nick_io")
	end
end)